@@ -19,7 +19,10 @@ using System.IO;
 using System.Text;
 using System.Runtime.InteropServices;
 using WebKit;
-#if ENABLE_DBUS
+#if DBUS_SHARP
+using DBus;
+using org.freedesktop.DBus;
+#elseif NDESK_DBUS
 using NDesk.DBus;
 using org.freedesktop.DBus;
 #endif
@@ -32,16 +35,16 @@ namespace Imendio.Blam {
 		Channel
 	};
 
-#if ENABLE_DBUS
-    [NDesk.DBus.Interface("org.gnome.feed.Reader")]
+#if NDESK_DBUS || DBUS_SHARP
+    [Interface("org.gnome.feed.Reader")]
 #endif
     public interface IFeedReader {
         bool Subscribe(string url);
         void SetOnline(bool value);
     }
 
-#if ENABLE_DBUS
-    [NDesk.DBus.Interface("org.gnome.Blam.Reader")]
+#if NDESK_DBUS || DBUS_SHARP
+    [Interface("org.gnome.Blam.Reader")]
 #endif
     public interface IBlamReader {
         void ShowWindow();
