@@ -7,7 +7,8 @@
 
 namespace Imendio.Blam {
     public delegate void BlamEventHandler      ();
-    public delegate void ChannelEventHandler   (Channel channel);
+    public delegate void ChannelEventHandler   (IChannel channel);
+    public delegate void ChannelGroupEventHandler (IChannel group, IChannel channel);
     public delegate void ActionFinishedHandler (string  status);
     public delegate void StringUpdatedHandler  (string  str);
 }
