@@ -15,7 +15,7 @@ namespace Imendio.Blam {
 
     class AboutDialog {
         [Widget] Gtk.AboutDialog aboutDialog = null;
-        
+
         public AboutDialog(Gtk.Window parent)
         {
             Glade.XML gladeXML = Glade.XML.FromAssembly("blam.glade",
@@ -34,6 +34,48 @@ namespace Imendio.Blam {
         
     }
 
+    class AddGroupDialog
+    {
+        [Widget] Gtk.Dialog addGroupDialog = null;
+        [Widget] Gtk.Entry groupName       = null;
+        [Widget] Gtk.Button ok             = null;
+
+        Application mApp = null;
+
+        public AddGroupDialog(Application app)
+        {
+            mApp = app;
+
+            Glade.XML gladeXML = Glade.XML.FromAssembly("blam.glade",
+                                 "addGroupDialog", null);
+            gladeXML.Autoconnect(this);
+            addGroupDialog.TransientFor = app.Window;
+            addGroupDialog.IconName = "blam";
+        }
+
+        public void Show()
+        {
+            groupName.Text = "";
+            addGroupDialog.ShowAll();
+        }
+
+        public void OkButtonClicked(object obj, EventArgs args)
+        {
+            ChannelGroup group = new ChannelGroup();
+            group.Name = groupName.Text;
+            mApp.CCollection.Groups.Add(group);
+            Gtk.TreeIter iter = (mApp.ChannelList.Model as TreeStore).AppendValues(group);
+            group.Iter = iter;
+
+            addGroupDialog.Hide();
+        }
+
+        public void CancelButtonClicked(object obj, EventArgs args)
+        {
+            addGroupDialog.Hide();
+        }
+    }
+
     class AddChannelDialog {
     [Widget] Gtk.Dialog addChannelDialog = null;
     [Widget] Gtk.Entry  urlEntry         = null;
@@ -147,7 +189,7 @@ namespace Imendio.Blam {
 	    removeChannelDialog.IconName = "blam";
 	}
 
-	public static void Show (Gtk.Window parent, ChannelCollection collection, Channel channel)
+	public static void Show (Gtk.Window parent, ChannelCollection collection, IChannel channel)
 	{
 	    if (removeDialog == null) {
 		removeDialog = new RemoveChannelDialog (parent, collection);
@@ -155,7 +197,7 @@ namespace Imendio.Blam {
 
 	    string name = "<b>" + channel.Name + "</b>";
 	  
-	    string str = String.Format (Catalog.GetString ("Do you want to remove the channel {0} from the channel list?"), name);
+	    string str = String.Format (Catalog.GetString ("Do you want to remove the channel or group {0} from the channel list?"), name);
 
 	    removeDialog.dialogTextLabel.Markup = str;
 	    
