@@ -155,29 +155,27 @@ namespace Imendio.Blam {
 			}
 
 			string entryText = "";
-			if (entry.Content == null || entry.Content.Length == 0) {
+            if (entry.Content == null || entry.Content.Length == 0) {
+                Console.Error.WriteLine("no content, title= {0}", this.Title);
                 if(entry.Summary.Text == null){
-                    entryText = "<p>There was no summary/content found for this entry. This is" +
+                    Console.Error.WriteLine("summary text null");
+                    this.Text = "<p>There was no summary/content found for this entry. This is" + 
                         " most likely a bug.</p>";
                 } else {
-                    entryText = entry.Summary.Text.Trim();
+                    this.Text = entry.Summary.Text.Trim();
                 }
-			} else {
-                AtomText text = entry.ContentByType("text/html");
-                if(text != null){
-                    entryText = text.Text;
-                } else {
-                    text = entry.ContentByType("application/xhtml+xml");
-                    if(text != null){
-                        entryText = text.Text;
+            } else {
+                foreach (AtomText content in entry.Content) {
+                    if (content.Type == "text/html" ||
+                        content.Type == "html" ||
+                        content.Type == "application/xhtml+xml") {
+                        if(!this.Text.Equals(content.Text.Trim())){
+                            this.Text = content.Text.Trim();
+                        }
+                        break;
                     }
                 }
-			}
-
-			if (this.Text.Equals(entryText) == false) {
-				this.Text = entryText;
-				return true;
-			}
+            }
 
 			return false;
 		}
