@@ -47,7 +47,7 @@ namespace Imendio.Blam {
         CellRendererPixbuf cell2 = new CellRendererPixbuf();
         iconColumn = new TreeViewColumn();
         iconColumn.PackStart(cell2, true);
-        iconColumn  .Sizing = TreeViewColumnSizing.Autosize;
+        iconColumn.Sizing = TreeViewColumnSizing.GrowOnly;
         iconColumn.Expand = false;
         iconColumn.SetCellDataFunc(cell2,
                    new TreeCellDataFunc(IconCellDataFunc));
@@ -287,13 +287,13 @@ namespace Imendio.Blam {
         string icon = null;
 
         if(item.Unread == true){
-            icon = "stock_book_red";
+            icon = Gnome.Stock.BookRed;
         } else {
-            icon = "stock_book_open";
+            icon = Gnome.Stock.BookOpen;
         }
 
         if(item.Old == true && item.Unread == true){
-            icon = "stock_book_green";
+            icon = Gnome.Stock.BookGreen;
         }
 
         if((cell as CellRendererPixbuf).IconName != icon){
