@@ -25,6 +25,7 @@ namespace Imendio.Blam {
         private WebSettings webSettings;
 #endif
 	private Imendio.Blam.Item currentItem;
+    private string baseDir = null;
 
 	public bool PageLoaded;
 
@@ -67,7 +68,13 @@ namespace Imendio.Blam {
 
 		webView.NavigationRequested += delegate (object sender, NavigationRequestedArgs args) {
         try {
+            /* Allow our local files to be downloaded. Needed to load the theme */
+            if(args.Request.Uri.StartsWith(baseDir)){
+                    args.RetVal = NavigationResponse.Accept;
+                    return;
+            }
             Gnome.Url.Show(args.Request.Uri);
+                    args.RetVal = NavigationResponse.Ignore;
         }
         catch (Exception e) {
             Console.Error.WriteLine("Couldn't show URL: " + args.Request.Uri + e.Message);
@@ -89,36 +96,14 @@ namespace Imendio.Blam {
         {
 			Theme theme = Application.TheApp.ThemeManager.CurrentTheme;
 
-            /* One of the variables should be set. */
-            string locale = Environment.GetEnvironmentVariable("LC_MESSAGES");
-
-            if(locale == null){
-                locale = Environment.GetEnvironmentVariable("LC_ALL");
-            }
-            if(locale == null){
-                locale = Environment.GetEnvironmentVariable("LC_TIME");
-            }
-            if(locale == null){
-                locale = Environment.GetEnvironmentVariable("LANGUAGE");
-            }
-            if(locale == null){
-                locale = Environment.GetEnvironmentVariable("LANG");
-            }
-            if(locale == null){
-                locale = "en"; /* Give up. */
-            }
-
-            if(locale.IndexOf('_') != -1){ /* There is a separator. Do en_US.UTF-8 -> en, eg.*/
-                locale = locale.Substring(0, locale.IndexOf('_'));
-            }
-
             string author  = (!"".Equals(currentItem.Author)) ? String.Format(Catalog.GetString("by {0}"), currentItem.Author) : "&nbsp;";
             string link    = Catalog.GetString("Show in browser");
             string pubdate = (!currentItem.PubDate.Equals(DateTime.MinValue)) ?
-                currentItem.PubDate.ToString("D", System.Globalization.CultureInfo.CreateSpecificCulture(locale)) : "&nbsp;";
+                currentItem.PubDate.ToString("D", System.Globalization.CultureInfo.CurrentUICulture) : "&nbsp;";
             string text    = HtmlUtils.EncodeUnicode(HtmlUtils.FixMarkup(currentItem.Text));
             string title   = HtmlUtils.Escape(currentItem.Title);
             string url     = currentItem.Link;
+            baseDir        = "file://" + theme.Path;
 
             string[] replaces = {
                 "author", author,
@@ -126,10 +111,11 @@ namespace Imendio.Blam {
                 "pubdate", pubdate,
                 "text", text,
                 "title", title,
-                "url", url
+                "url", url,
+                "localbase", baseDir
             };
 
-						webView.LoadString (theme.Render(replaces), "text/html", "utf8", "file://" + theme.Path + "/");
+			webView.LoadString(theme.Render(replaces), null, null, baseDir);
 	}
 
         private void SetFonts ()
